@@ -121,11 +121,11 @@ class account():
         self.locationSetup=True
         loop.run()
 
-    def stopLocation(self):
+    def stop_Location(self):
         print "stop location tracking"
         self.control.stop()
 
-    def startLocation(self):
+    def start_Location(self):
         print "start location tracking"
         self.control.start()
         
@@ -1526,8 +1526,8 @@ class account():
     def on_changed(self,device, data):
         if self.stopLocation:
             #stoppping location tracking
-            #data.stop()
-            print "disabled stop location"
+            data.stop()
+            self.stopLocation = False
         if not device:
             return
         if device.fix:
